//Source file: PAMACPSNotificationData.java
//Date: February 2004
//Presence and Availability Management Data Types for 3GPP TS 29.198-14 V6.0.0, Release 6

package org.csapi.jr.se.pam;

/**
 * This is a Sequence of Data Elements to specify the data that is provided in the notifications for capability presence set events.
 * 
 */
public final class PAMACPSNotificationData implements java.io.Serializable {

    private String agent;
    private String capability;
    private String[] attributeNames;

    /**
     * Creates a new PAMACPSNotificationData instance.
     */
    public PAMACPSNotificationData () {}

    /**
     * Creates a new PAMACPSNotificationData instance.
     * @param _agent   Contains the name of the agent whose capability presence has changed.
     * @param _capability   Specifies the capability for which the presence has changed.
     * @param _attributeNames   Contains the attribute names that have changed in value.
     */
    public PAMACPSNotificationData (String _agent, String _capability, String[] _attributeNames) {

        this.agent = _agent;
        this.capability = _capability;
        this.attributeNames = _attributeNames;
    }

    /**
     * This method returns a agent.
     * 
     * @return a String value
     */
    public String getAgent() {
        return agent;
    }

    /**
     * This method returns a capability.
     * 
     * @return a String value
     */
    public String getCapability() {
        return capability;
    }

    /**
     * This method returns a attributeNames.
     * 
     * @return a String[] value
     */
    public String[] getAttributeNames() {
        return attributeNames;
    }


    /**
     * This method sets a agent.
     */ 
    public void setAgent(String agent) {
        this.agent = agent;
    }

    /**
     * This method sets a capability.
     */ 
    public void setCapability(String capability) {
        this.capability = capability;
    }

    /**
     * This method sets a attributeNames.
     */ 
    public void setAttributeNames(String[] attributeNames) {
        this.attributeNames = attributeNames;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMACPSNotificationData)) {
            return false;
        } 
        PAMACPSNotificationData pAMACPSNotificationData = (PAMACPSNotificationData) o;
        if(!(this.agent == pAMACPSNotificationData.agent))  {
            return false;
        }
        if(!(this.capability == pAMACPSNotificationData.capability))  {
            return false;
        }
        if(!(this.attributeNames == pAMACPSNotificationData.attributeNames))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMACPSNotificationData

