//Source file: PAMAPSEventData.java
//Date: February 2004
//Presence and Availability Management Data Types for 3GPP TS 29.198-14 V6.0.0, Release 6

package org.csapi.jr.se.pam;

/**
 * This is a Sequence of Data Elements to specify the input data for subscribing to agent presence set events. The event is registered for changes in any of the named attributes. If no attributes are named, then the event is registered for all attributes in the presence information.
 * 
 */
public final class PAMAPSEventData implements java.io.Serializable {

    private String[] agentName;
    private String[] agentType;
    private String[] attributeNames;
    private long reportingPeriod;

    /**
     * Creates a new PAMAPSEventData instance.
     */
    public PAMAPSEventData () {}

    /**
     * Creates a new PAMAPSEventData instance.
     * @param _agentName   Specifies the name of the agent for which the assignment is to be notified. Can be an empty array if notification is required for any agent instance.
     * @param _agentType   specifies the type of the agent for which this notification is requested if the agentName is specified as an empty array. Can be an empty array if notification required for agents of any type.
     * @param _attributeNames   Specifies attributes of interest. Can be an empty array
     * @param _reportingPeriod   Specifies the interval for periodic reporting (regardless of change). If -1, the event notification happens only on a change. If 0, there is a single immediate notification.
     */
    public PAMAPSEventData (String[] _agentName, String[] _agentType, String[] _attributeNames, long _reportingPeriod) {

        this.agentName = _agentName;
        this.agentType = _agentType;
        this.attributeNames = _attributeNames;
        this.reportingPeriod = _reportingPeriod;
    }

    /**
     * This method returns a agentName.
     * 
     * @return a String[] value
     */
    public String[] getAgentName() {
        return agentName;
    }

    /**
     * This method returns a agentType.
     * 
     * @return a String[] value
     */
    public String[] getAgentType() {
        return agentType;
    }

    /**
     * This method returns a attributeNames.
     * 
     * @return a String[] value
     */
    public String[] getAttributeNames() {
        return attributeNames;
    }

    /**
     * This method returns a reportingPeriod.
     * 
     * @return a long value
     */
    public long getReportingPeriod() {
        return reportingPeriod;
    }


    /**
     * This method sets a agentName.
     */ 
    public void setAgentName(String[] agentName) {
        this.agentName = agentName;
    }

    /**
     * This method sets a agentType.
     */ 
    public void setAgentType(String[] agentType) {
        this.agentType = agentType;
    }

    /**
     * This method sets a attributeNames.
     */ 
    public void setAttributeNames(String[] attributeNames) {
        this.attributeNames = attributeNames;
    }

    /**
     * This method sets a reportingPeriod.
     */ 
    public void setReportingPeriod(long reportingPeriod) {
        this.reportingPeriod = reportingPeriod;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMAPSEventData)) {
            return false;
        } 
        PAMAPSEventData pAMAPSEventData = (PAMAPSEventData) o;
        if(!(this.agentName == pAMAPSEventData.agentName))  {
            return false;
        }
        if(!(this.reportingPeriod == pAMAPSEventData.reportingPeriod))  {
            return false;
        }
        if(!(this.attributeNames == pAMAPSEventData.attributeNames))  {
            return false;
        }
        if(!(this.agentType == pAMAPSEventData.agentType))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMAPSEventData

